pub enum BodyType {
Dynamic,
Static,
Kinematic,
}Expand description
Whether a body is affected by forces and collisions.
Variants
Dynamic
Affected by forces and collisions.
Static
Not affected by forces, but participates in collisions (infinite mass).
Kinematic
Moved by user code, pushes dynamic bodies but isn’t affected by them.