RayHit

Struct RayHit 

pub struct RayHit<const D: usize> {
    pub body: BodyHandle,
    pub distance: f64,
    pub point: SVector<f64, D>,
    pub normal: SVector<f64, D>,
}
Result of a ray cast against the physics world.

Fields

body: BodyHandle

The body that was hit.

distance: f64

Distance from the ray origin to the hit point.

point: SVector<f64, D>

Hit point in world space.

normal: SVector<f64, D>

Surface normal at the hit point (pointing toward the ray origin).